@@ -1,3 +1,4 @@
+import inspect
 import re
 import traceback
 import warnings
@@ -73,21 +74,20 @@ def _get_help_record(opt):
 
     extras = []
 
-    if opt.default is not None and opt.show_default:
-        if isinstance(opt.show_default, str):
-            # Starting from Click 7.0 this can be a string as well. This is
-            # mostly useful when the default is not a constant and
-            # documentation thus needs a manually written string.
-            extras.append(':default: %s' % opt.show_default)
-        else:
-            extras.append(
-                ':default: %s'
-                % (
-                    ', '.join('%s' % d for d in opt.default)
-                    if isinstance(opt.default, (list, tuple))
-                    else opt.default,
-                )
+    if isinstance(opt.show_default, str):
+        # Starting from Click 7.0 show_default can be a string. This is
+        # mostly useful when the default is not a constant and
+        # documentation thus needs a manually written string.
+        extras.append(':default: %s' % opt.show_default)
+    elif opt.default is not None and opt.show_default:
+        extras.append(
+            ':default: %s'
+            % (
+                ', '.join(str(d) for d in opt.default)
+                if isinstance(opt.default, (list, tuple))
+                else opt.default,
             )
+        )
 
     if isinstance(opt.type, click.Choice):
         extras.append(':options: %s' % ' | '.join(str(x) for x in opt.type.choices))
@@ -101,17 +101,8 @@ def _get_help_record(opt):
     return ', '.join(rv), '\n'.join(out)
 
 
-def _format_description(ctx):
-    """Format the description for a given `click.Command`.
-
-    We parse this as reStructuredText, allowing users to embed rich
-    information in their help messages if they so choose.
-    """
-    help_string = ctx.command.help or ctx.command.short_help
-    if not help_string:
-        return
-
-    help_string = ANSI_ESC_SEQ_RE.sub('', help_string)
+def _format_help(help_string):
+    help_string = inspect.cleandoc(ANSI_ESC_SEQ_RE.sub('', help_string))
 
     bar_enabled = False
     for line in statemachine.string2lines(
@@ -127,6 +118,17 @@ def _format_description(ctx):
     yield ''
 
 
+def _format_description(ctx):
+    """Format the description for a given `click.Command`.
+
+    We parse this as reStructuredText, allowing users to embed rich
+    information in their help messages if they so choose.
+    """
+    help_string = ctx.command.help or ctx.command.short_help
+    if help_string:
+        yield from _format_help(help_string)
+
+
 def _format_usage(ctx):
     """Format the usage for a `click.Command`."""
     yield '.. code-block:: shell'
@@ -236,16 +238,8 @@ def _format_epilog(ctx):
     We parse this as reStructuredText, allowing users to embed rich
     information in their help messages if they so choose.
     """
-    if not ctx.command.epilog:
-        return
-
-    for line in statemachine.string2lines(
-        ANSI_ESC_SEQ_RE.sub('', ctx.command.epilog),
-        tab_width=4,
-        convert_whitespace=True,
-    ):
-        yield line
-    yield ''
+    if ctx.command.epilog:
+        yield from _format_help(ctx.command.epilog)
 
 
 def _get_lazyload_commands(multicommand):
